@@ -6,7 +6,6 @@
 #include <cmath>
 #include <cstring>
 #include <iomanip>
-#include <iostream>
 #include <sstream>
 
 #include <OpenColorIO/OpenColorIO.h>
@@ -42,7 +41,9 @@ namespace Shader
     };
     inline LimitsDiff ValidateInf(float x1, float x2)
     {
-        if (fabs(x1) < largeThreshold && fabs(x2) < largeThreshold)
+        if ( (fabs(x1) < largeThreshold && fabs(x2) < largeThreshold) 
+            // If either value is NaN, consider this a NaN error rather than an Inf error.
+            || (std::isnan(x1) || std::isnan(x2)) )
         {
             return NOT_APPLICABLE;
         }
@@ -429,34 +430,47 @@ namespace
 
         const OCIOGPUTest::CustomValues::Values & image = test->getCustomValues().m_inputValues;
         float diff = 0.0f;
+        // Initialize these to a known reference value, if any of the four component checks
+        // below fail, it will be set to the index of the last failure. Only the last failure
+        // is printed below.
         size_t idxDiff = invalidIndex;
         size_t idxNan = invalidIndex;
         size_t idxInf = invalidIndex;
+        constexpr float huge = std::numeric_limits<float>::max();
+        float minVals[4] = {huge, huge, huge, huge};
+        float maxVals[4] = {-huge, -huge, -huge, -huge};
         const bool relativeTest = test->getRelativeComparison();
         for(size_t idx=0; idx<(width*height); ++idx)
         {
-            DiffComponent(cpuImage, gpuImage, 4 * idx + 0, relativeTest, expectMinValue,
-                          diff, idxDiff, idxInf, idxNan);
-            DiffComponent(cpuImage, gpuImage, 4 * idx + 1, relativeTest, expectMinValue,
-                          diff, idxDiff, idxInf, idxNan);
-            DiffComponent(cpuImage, gpuImage, 4 * idx + 2, relativeTest, expectMinValue,
-                          diff, idxDiff, idxInf, idxNan);
-            DiffComponent(cpuImage, gpuImage, 4 * idx + 3, relativeTest, expectMinValue,
-                          diff, idxDiff, idxInf, idxNan);
+            for(size_t chan=0; chan<4; ++chan)
+            {
+                DiffComponent(cpuImage, gpuImage, 4 * idx + chan, relativeTest, expectMinValue,
+                              diff, idxDiff, idxInf, idxNan);
+                minVals[chan] = std::min(minVals[chan], 
+                                std::isinf(gpuImage[4 * idx + chan]) ? huge: gpuImage[4 * idx + chan]);
+                maxVals[chan] = std::max(maxVals[chan], 
+                                std::isinf(gpuImage[4 * idx + chan]) ? -huge: gpuImage[4 * idx + chan]);
+            }
         }
 
         size_t componentIdx = idxDiff % 4;
         size_t pixelIdx = idxDiff / 4;
-        if (diff > epsilon || idxInf != invalidIndex || idxNan != invalidIndex)
+        if (diff > epsilon || idxInf != invalidIndex || idxNan != invalidIndex || test->isPrintMinMax())
         {
             std::stringstream err;
+            err << std::setprecision(10);
+            err << "\n\nGPU max vals = {" 
+                << maxVals[0] << ", " << maxVals[1] << ", " << maxVals[2] << ", " << maxVals[3] << "}\n"
+                << "GPU min vals = {" 
+                << minVals[0] << ", " << minVals[1] << ", " << minVals[2] << ", " << minVals[3] << "}\n";
+
             err << std::setprecision(10)
                 << "\nMaximum error: " << diff << " at pixel: " << pixelIdx
                 << " on component " << componentIdx;
             if (diff > epsilon)
             {
                 err << std::setprecision(10)
-                    << " larger than epsilon.\nscr = {"
+                    << " larger than epsilon.\nsrc = {"
                     << image[4 * pixelIdx + 0] << ", " << image[4 * pixelIdx + 1] << ", "
                     << image[4 * pixelIdx + 2] << ", " << image[4 * pixelIdx + 3] << "}"
                     << "\ncpu = {"
